summaryrefslogtreecommitdiff
path: root/src/fs/paths.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/fs/paths.cpp')
-rw-r--r--src/fs/paths.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/fs/paths.cpp b/src/fs/paths.cpp
index 942f69471..cc5092c69 100644
--- a/src/fs/paths.cpp
+++ b/src/fs/paths.cpp
@@ -1,8 +1,8 @@
/*
* The ManaPlus Client
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -171,13 +171,13 @@ std::string removeLast(const std::string &str)
#ifdef WIN32
std::string getSelfName()
{
- return "manaplus.exe";
+ return "manaverse.exe";
}
#elif defined(__APPLE__)
std::string getSelfName()
{
- return "manaplus.exe";
+ return "manaverse.exe";
}
#elif defined __linux__ || defined __linux
@@ -1,8 +1,8 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2011-2019 The ManaPlus Developers
*
@@ -1,8 +1,8 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify